<?php  
/* 
Plugin Name: Map Images
Plugin URI: http://www.danmorella.com/wordpress/?p=749
Description: Maps gps tagged images on a google map.
Version: 1.0.1 
Author: Dan Morella
Author URI: http://www.danmorella.com
*/  
/*  Copyright 2013  Dan Morella  (email : wpplugins@danmorella.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

//If being accessed by the administrator, include the admin.php file.
if ( is_admin() )
{
	require_once dirname( __FILE__ ) . '/admin.php';
}

//Get the map images options from the WordPress database.
$mapimages_options = get_option('mapimages_options');

//mapimages_gpsDecimal function
//Convert GPS degrees to decimals
function mapimages_gpsDecimal($deg, $min, $sec, $hem) 
{
	$d = $deg + ((($min/60) + ($sec/3600))/100);
	return ($hem=='S' || $hem=='W') ? $d*=-1 : $d;
}
	
//mapimages_inpost function
//This function parses all images in a post and adds the google map with markers, then returns the new post
function mapimages_inpost($content)
{
	//Include the WordPress post variable
	global $post;
	//Include the map images options
	global $mapimages_options;

	//new content for the google maps
	$additionalContent = "";

	//create the div where the google map will reside
	$additionalContent .= "\n <div id=\"map_canvas".$post->ID."\" style=\"width:".$mapimages_options["plugin_mapwidth"]."px; height:".$mapimages_options["plugin_mapheight"]."px;\"></div>";
	$additionalContent .= "\n ";

	//create the java script 
	$additionalContent .= "\n <script>";

	//add a function to the mapimages_inpostJavaScriptArray that will create a new google map using the Google Maps API
	$additionalContent .= "\n   mapimages_inpostJavaScriptArray.push(function(){var map".$post->ID." = new google.maps.Map(document.getElementById(\"map_canvas".$post->ID."\"), mapOptions".$post->ID."); return map".$post->ID.";});";

	//push the name of the new google map variable to the mapimages_inpostMapNameArray
	$additionalContent .= "\n   mapimages_inpostMapNameArray.push('map".$post->ID."');";

	//create the javascript object with the map options for this google map
	$additionalContent .= "\n   var mapOptions".$post->ID." = {";
	$additionalContent .= "\n     center: new google.maps.LatLng(".$mapimages_options["googlemaps_defaultcenter"]."),";
	$additionalContent .= "\n     zoom: ".$mapimages_options["googlemaps_defaultzoom"].",";
	$additionalContent .= "\n     mapTypeId: google.maps.MapTypeId.".$mapimages_options["googlemaps_maptype"]."";
	$additionalContent .= "\n   };";

	//create a new array for all the markers that will be added to the google map.
	$additionalContent .= "\n  currentMarkerArray = new Array();";

	//split the current post by all image tags and loop through them
	$tempContent = explode("<img",$content);

	//if no images are found, just return content with no google map.
	if(count($tempContent) == 1)
		return $content;

	$imageWithLocationData = false;
	for($i=0;$i<count($tempContent)-1;$i++)
	{
		//locate the url of the image
		$tempLocation = strripos($tempContent[$i],"href=\"");

		//if the url exists, then parse the image
		if($tempLocation !== false)
		{
			//store the URL in a variable
			$tempContent[$i] = substr($tempContent[$i],$tempLocation+6);
			$tempLocation = strpos($tempContent[$i],"\"");
			$tempContent[$i] = substr($tempContent[$i],0,$tempLocation);

			//get the exif data from the image.  If the image is local, get the full URL so all images can be processed the same.
			$exif_data = exif_read_data(str_replace(($_SERVER['HTTPS'] == "" ? "http://":"https://").$_SERVER['SERVER_NAME'],$_SERVER["DOCUMENT_ROOT"],$tempContent[$i]));

			//if the exif GPS data exists, add a marker to the map.
			if($exif_data != false && (array_key_exists('GPSLongitude',$exif_data) || array_key_exists('GPSLatitude',$exif_data) || array_key_exists('GPSLongitudeRef',$exif_data) || array_key_exists('GPSLatitudeRef',$exif_data)))
			{
			
				$imageWithLocationData = true;
			
				//extract the longitude and latitude from the exif data
				$egeoLong = $exif_data['GPSLongitude'];
				$egeoLat = $exif_data['GPSLatitude'];
				$egeoLongR = $exif_data['GPSLongitudeRef'];
				$egeoLatR = $exif_data['GPSLatitudeRef'];

				//convert the degree data to decimal for google maps api
				$geoLong = mapimages_gpsDecimal($egeoLong[0], $egeoLong[1], $egeoLong[2], $egeoLongR);
				$geoLat = mapimages_gpsDecimal($egeoLat[0], $egeoLat[1], $egeoLat[2], $egeoLatR);

				//create the new point using the gps data
				$additionalContent .= "\n  var tmpPoint = new google.maps.LatLng(".$geoLat.", ".$geoLong.")";

				//add the new marker to the currentMarkerArray so it can be added to the google map once it has been created.
				$additionalContent .= "\n   currentMarkerArray.push(new google.maps.Marker({";
				$additionalContent .= "\n     draggable:false,";
				$additionalContent .= "\n     animation: google.maps.Animation.".$mapimages_options["googlemaps_animation"].",";
				$additionalContent .= "\n     position: tmpPoint";
				$additionalContent .= "\n   }));";
			}
		}
	}

	//push the currentMarkerArray to the mapimages_inpostMarkerMapArray
	$additionalContent .= "\n   mapimages_inpostMarkerMapArray.push(currentMarkerArray);";

	$additionalContent .= "\n </script>";

	//if no marker exists, skip the map, otherwise should the map be appended before the post or after the post.
	if(!$imageWithLocationData)
	{
		return $content;
	}
	else if($mapimages_options["plugin_locationinpost"] == "BEFORE")
	{
		return $additionalContent." ".$content;
	}
	else
	{
		return $content." ".$additionalContent;
	}
}

//mapimages_inpostHead function
//This function creates all the java script variables that will hold the google map objects for the page.
function mapimages_inpostHead()
{
	echo "\n<script>";

	//This varaible holds the google map objects for all posts on the current page
	echo "\n    var mapimages_inpostJavaScriptArray = new Array();";

	//This variable holds the marker arrays for each of the google maps on the current page	
	echo "\n    var mapimages_inpostMarkerMapArray = new Array();";

	//This variable holds the google map names for all the posts on the current page
	echo "\n    var mapimages_inpostMapNameArray = new Array();";

	//This function creates all the google map objects, adds the markers, and loads them.
	echo "\n    function mapimages_inpostInitialize()";
	echo "\n    {";
	echo "\n      for(i=0;i<mapimages_inpostJavaScriptArray.length;i++)";
	echo "\n      {";
	echo "\n        temp=mapimages_inpostJavaScriptArray[i]();";

	//The zoom level of the google map is dynamically updated to show all markers in the space provided.
	echo "\n        var bounds = new google.maps.LatLngBounds();";
	echo "\n        for(j=0;j<mapimages_inpostMarkerMapArray[i].length;j++)";
	echo "\n        {";
	echo "\n          mapimages_inpostMarkerMapArray[i][j].setMap(temp);";
	echo "\n          bounds.extend(mapimages_inpostMarkerMapArray[i][j].getPosition());";
	echo "\n        }";
	echo "\n        temp.fitBounds(bounds);";

	echo "\n      }";
	echo "\n    }";

	//once the page has loaded completely begin creating and displaying the google maps
	echo "\n    if (window.attachEvent) {window.attachEvent('onload', mapimages_inpostInitialize);}";
	echo "\n    else if (window.addEventListener) {window.addEventListener('load', mapimages_inpostInitialize, false);}";
	echo "\n    else {document.addEventListener('load', mapimages_inpostInitialize, false);} ";

	echo "\n</script>";
}

//add the google maps api code
wp_enqueue_script('GoogleMapsAPI', 'https://maps.googleapis.com/maps/api/js?key='.$mapimages_options["googlemaps_key"].'&sensor=false');

//add the code for this plugin to process images in posts
add_filter( 'the_content', 'mapimages_inpost', 5);

//add the code to declare all javascript variables and allow processing after the page has finished loading
add_action('wp_head', 'mapimages_inpostHead');
?>